@@ -7,18 +7,18 @@ Do not add this file to the repository.
 
 import datetime
 
-version = '1.10'
-date = 'Fri Oct  2 02:54:04 2015'
+version = '1.11'
+date = 'Sun Jan 31 00:43:59 2016'
 
 # Was NetworkX built from a development version? If so, remember that the major
 # and minor versions reference the "target" (rather than "current") release.
 dev = False
 
 # Format: (name, major, min, revision)
-version_info = ('networkx', '1', '10', None)
+version_info = ('networkx', '1', '11', None)
 
 # Format: a 'datetime.datetime' instance
-date_info = datetime.datetime(2015, 10, 2, 2, 54, 4, 567752)
+date_info = datetime.datetime(2016, 1, 31, 0, 43, 59, 84262)
 
 # Format: (vcs, vcs_tuple)
 vcs_info = (None, (None, None))
