@@ -8,9 +8,9 @@ This graph is sometimes called the Erdős-Rényi graph
 but is different from G{n,p} or binomial_graph which is also
 sometimes called the Erdős-Rényi graph.
 """
-__author__ = """Aric Hagberg (hagberg@lanl.gov)"""
-__credits__ = """"""
-#    Copyright (C) 2004-2015 by 
+# Author: Aric Hagberg (hagberg@lanl.gov)
+
+#    Copyright (C) 2004-2016 by
 #    Aric Hagberg <hagberg@lanl.gov>
 #    Dan Schult <dschult@colgate.edu>
 #    Pieter Swart <swart@lanl.gov>
